==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/lex/kotlin/inputs/IntentRejectionStatementMessageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.lex.kotlin.inputs

import com.pulumi.aws.lex.inputs.IntentRejectionStatementMessageArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property content The text of the message. Must be less than or equal to 1000 characters in length.
 * @property contentType The content type of the message string.
 * @property groupNumber Identifies the message group that the message belongs to. When a group
 * is assigned to a message, Amazon Lex returns one message from each group in the response. Must be a number between 1 and 5 (inclusive).
 */
public data class IntentRejectionStatementMessageArgs(
    public val content: Output<String>,
    public val contentType: Output<String>,
    public val groupNumber: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.aws.lex.inputs.IntentRejectionStatementMessageArgs> {
    override fun toJava(): com.pulumi.aws.lex.inputs.IntentRejectionStatementMessageArgs =
        com.pulumi.aws.lex.inputs.IntentRejectionStatementMessageArgs.builder()
            .content(content.applyValue({ args0 -> args0 }))
            .contentType(contentType.applyValue({ args0 -> args0 }))
            .groupNumber(groupNumber?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IntentRejectionStatementMessageArgs].
 */
@PulumiTagMarker
public class IntentRejectionStatementMessageArgsBuilder internal constructor() {
    private var content: Output<String>? = null

    private var contentType: Output<String>? = null

    private var groupNumber: Output<Int>? = null

    /**
     * @param value The text of the message. Must be less than or equal to 1000 characters in length.
     */
    @JvmName("kimaioybbndqwddo")
    public suspend fun content(`value`: Output<String>) {
        this.content = value
    }

    /**
     * @param value The content type of the message string.
     */
    @JvmName("hngnyqaxlkatqrkf")
    public suspend fun contentType(`value`: Output<String>) {
        this.contentType = value
    }

    /**
     * @param value Identifies the message group that the message belongs to. When a group
     * is assigned to a message, Amazon Lex returns one message from each group in the response. Must be a number between 1 and 5 (inclusive).
     */
    @JvmName("ltdklyulwevwmpyw")
    public suspend fun groupNumber(`value`: Output<Int>) {
        this.groupNumber = value
    }

    /**
     * @param value The text of the message. Must be less than or equal to 1000 characters in length.
     */
    @JvmName("fwpoyqngdtrssdci")
    public suspend fun content(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.content = mapped
    }

    /**
     * @param value The content type of the message string.
     */
    @JvmName("kvrxydjmtfkpmxch")
    public suspend fun contentType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.contentType = mapped
    }

    /**
     * @param value Identifies the message group that the message belongs to. When a group
     * is assigned to a message, Amazon Lex returns one message from each group in the response. Must be a number between 1 and 5 (inclusive).
     */
    @JvmName("bxaerrfaqdbklmuc")
    public suspend fun groupNumber(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupNumber = mapped
    }

    internal fun build(): IntentRejectionStatementMessageArgs = IntentRejectionStatementMessageArgs(
        content = content ?: throw PulumiNullFieldException("content"),
        contentType = contentType ?: throw PulumiNullFieldException("contentType"),
        groupNumber = groupNumber,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/lex/kotlin/inputs/IntentRejectionStatementMessageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.lex.kotlin.inputs

import com.pulumi.aws.lex.inputs.IntentRejectionStatementMessageArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property content The text of the message. Must be less than or equal to 1000 characters in length.
 * @property contentType The content type of the message string.
 * @property groupNumber Identifies the message group that the message belongs to. When a group
 * is assigned to a message, Amazon Lex returns one message from each group in the response. Must be a number between 1 and 5 (inclusive).
 */
public data class IntentRejectionStatementMessageArgs(
    public val content: Output<String>,
    public val contentType: Output<String>,
    public val groupNumber: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.aws.lex.inputs.IntentRejectionStatementMessageArgs> {
    override fun toJava(): com.pulumi.aws.lex.inputs.IntentRejectionStatementMessageArgs =
        com.pulumi.aws.lex.inputs.IntentRejectionStatementMessageArgs.builder()
            .content(content.applyValue({ args0 -> args0 }))
            .contentType(contentType.applyValue({ args0 -> args0 }))
            .groupNumber(groupNumber?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [IntentRejectionStatementMessageArgs].
 */
@PulumiTagMarker
public class IntentRejectionStatementMessageArgsBuilder internal constructor() {
    private var content: Output<String>? = null

    private var contentType: Output<String>? = null

    private var groupNumber: Output<Int>? = null

    /**
     * @param value The text of the message. Must be less than or equal to 1000 characters in length.
     */
    @JvmName("wagfoppnxkwmtjwx")
    public suspend fun content(`value`: Output<String>) {
        this.content = value
    }

    /**
     * @param value The content type of the message string.
     */
    @JvmName("mcwgmawrnohdoqat")
    public suspend fun contentType(`value`: Output<String>) {
        this.contentType = value
    }

    /**
     * @param value Identifies the message group that the message belongs to. When a group
     * is assigned to a message, Amazon Lex returns one message from each group in the response. Must be a number between 1 and 5 (inclusive).
     */
    @JvmName("pnpoaxtdjrfhxlah")
    public suspend fun groupNumber(`value`: Output<Int>) {
        this.groupNumber = value
    }

    /**
     * @param value The text of the message. Must be less than or equal to 1000 characters in length.
     */
    @JvmName("ygddnwvjqvrggtob")
    public suspend fun content(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.content = mapped
    }

    /**
     * @param value The content type of the message string.
     */
    @JvmName("osmfnxnxkospamto")
    public suspend fun contentType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.contentType = mapped
    }

    /**
     * @param value Identifies the message group that the message belongs to. When a group
     * is assigned to a message, Amazon Lex returns one message from each group in the response. Must be a number between 1 and 5 (inclusive).
     */
    @JvmName("ytfkhibmmcofgtvg")
    public suspend fun groupNumber(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupNumber = mapped
    }

    internal fun build(): IntentRejectionStatementMessageArgs = IntentRejectionStatementMessageArgs(
        content = content ?: throw PulumiNullFieldException("content"),
        contentType = contentType ?: throw PulumiNullFieldException("contentType"),
        groupNumber = groupNumber,
    )
}
